/*
 * nisync_reg.h
 *
 * Copyright (c) 2013-2018 National Instruments
 *
 * Author: Mike Hoogendyk <mike.hoogendyk@ni.com>
 *
 */
#ifndef NISYNC_REG_H_
#define NISYNC_REG_H_

#include <linux/types.h>
#include <asm/io.h>

struct tns_regs {
	u32 signature;					/* 0x0000 */
	u32 revision_reg;				/* 0x0004 */
	u32 oldest_compatible_revision;			/* 0x0008 */
	u32 _reserved_000C_0014[0x3];			/* 0x000C - 0x0014 */
	u32 hardware_revision;				/* 0x0018 */
	u32 _reserved_001C;				/* 0x001C */
	u32 oscillator_freq;				/* 0x0020 */
	u32 nco_width;					/* 0x0024 */
	u32 system_time_high_word;			/* 0x0028 */
	u32 system_time_low_word;			/* 0x002C */
	u32 board_status;				/* 0x0030 */
	u32 future_time_latency;			/* 0x0034 */
	u32 input_timestamp_latency;			/* 0x0038 */
	u32 system_time_latency;			/* 0x003C */
	u32 enet_transmit_latency;			/* 0x0040 */
	u16 enet_receive_latency;			/* 0x0044 */
	u32 partial_clear_operation_latency;		/* 0x0048 */
	u32 _reserved_004C_0058[0x4];			/* 0x004C - 0x0058 */
	u32 clk10_timestamp_reg;			/* 0x005C */
	u32 _reserved_0060_009C[0x10];			/* 0x0060 - 0x009C */
	u32 input_timestamp_buffer_read;		/* 0x00A0 */
	u32 _reserved_00A4_0AC[0x3];			/* 0x00A4 - 0x00AC */
	u32 irig_timeofday;				/* 0x00B0 */
	u32 irig_year_and_straight_binary_seconds;	/* 0x00B4 */
	u32 irig_timestamp_high;			/* 0x00B8 */
	u32 irig_timestamp_low;				/* 0x00BC */
	u32 _reserved_00C0_0104[0x12];			/* 0x00C0 - 0x0104 */
	u32 int_status_read_to_clear;			/* 0x0108 */
	u32 _reserved_010C;				/* 0x010C */
	u32 int_status;					/* 0x0110 */
	u32 _reserved_0114_014C[0xF];			/* 0x0114 - 0x014C */
	u32 global_board_settings_enable;		/* 0x0150 */
	u32 global_board_settings_disable;		/* 0x0154 */
	u32 led_enable;					/* 0x0158 */
	u32 led_disable;				/* 0x015C */
	u32 clocking_settings_enable;			/* 0x0160 */
	u32 clocking_settings_disable;			/* 0x0164 */
	u32 _reserved_0168_01FC[0x26];			/* 0x0168 - 0x01FC */
	u32 incoming_packet_fifo_read;			/* 0x0200 */
	u32 _reserved_0204_0208[0x2];			/* 0x0204 - 0x0208 */
	u32 outgoing_packet_fifo_read;			/* 0x020C */
	u32 _reserved_0210_024C[0x10];			/* 0x0210 - 0x024C */
	u32 incoming_instr_fifo;			/* 0x0250 */
	u32 outgoing_instr_fifo;			/* 0x0254 */
	u32 incoming_packet_buffer_control_enable;	/* 0x0258 */
	u32 incoming_packet_buffer_control_disable;	/* 0x025C */
	u32 incoming_packet_buffer_status;		/* 0x0260 */
	u32 outgoing_packet_buffer_control_enable;	/* 0x0264 */
	u32 outgoing_packet_buffer_control_disable;	/* 0x0268 */
	u32 outgoing_packet_buffer_status;		/* 0x026C */
	u32 ethernet_packet_latencies_1000;             /* 0x0270 */
	u32 _reserved_0274_034C[0x37];			/* 0x0274 - 0x034C */
	u32 input_timestamp_buffer_control_enable;	/* 0x0350 */
	u32 input_timestamp_buffer_control_disable;	/* 0x0354 */
	u32 _reserved_0358;				/* 0x0358 */
	u32 input_timestamp_buffer_watermark;		/* 0x035C */
	u32 _reserved_0360_0364[0x2];			/* 0x0360 - 0x0364 */
	u32 input_timestamp_buffer_status;		/* 0x0368 */
	u32 _reserved_036C_0404[0x27];			/* 0x036C - 0x0404 */
	u32 rtsi7_future_time_clock_period;		/* 0x0408 */
	u32 rtsi6_future_time_clock_period;		/* 0x040C */
	u32 rtsi5_future_time_clock_period;		/* 0x0410 */
	u32 rtsi4_future_time_clock_period;		/* 0x0414 */
	u32 rtsi3_future_time_clock_period;		/* 0x0418 */
	u32 rtsi2_future_time_clock_period;		/* 0x041C */
	u32 rtsi1_future_time_clock_period;		/* 0x0420 */
	u32 rtsi0_future_time_clock_period;		/* 0x0424 */
	u32 pfi2_future_time_clock_period;		/* 0x0428 */
	u32 pfi1_future_time_clock_period;		/* 0x042C */
	u32 pfi0_future_time_clock_period;		/* 0x0430 */
	u32 _reserved_0434_0450[0x8];			/* 0x0434 - 0x0450 */
	u32 rtsi7_future_time_clock_duty_cycle;		/* 0x0454 */
	u32 rtsi6_future_time_clock_duty_cycle;		/* 0x0458 */
	u32 rtsi5_future_time_clock_duty_cycle;		/* 0x045C */
	u32 rtsi4_future_time_clock_duty_cycle;		/* 0x0460 */
	u32 rtsi3_future_time_clock_duty_cycle;		/* 0x0464 */
	u32 rtsi2_future_time_clock_duty_cycle;		/* 0x0468 */
	u32 rtsi1_future_time_clock_duty_cycle;		/* 0x046C */
	u32 rtsi0_future_time_clock_duty_cycle;		/* 0x0470 */
	u32 pfi2_future_time_clock_duty_cycle;		/* 0x0474 */
	u32 pfi1_future_time_clock_duty_cycle;		/* 0x0478 */
	u32 pfi0_future_time_clock_duty_cycle;		/* 0x047C */
	u32 _reserved_0480_049C[0x8];			/* 0x0480 - 0x049C */
	u32 star0_future_time_clock_duty_cycle;		/* 0x04A0 */
	u32 star1_future_time_clock_duty_cycle;		/* 0x04A4 */
	u32 star2_future_time_clock_duty_cycle;		/* 0x04A8 */
	u32 star3_future_time_clock_duty_cycle;		/* 0x04AC */
	u32 star4_future_time_clock_duty_cycle;		/* 0x04B0 */
	u32 star5_future_time_clock_duty_cycle;		/* 0x04B4 */
	u32 star6_future_time_clock_duty_cycle;		/* 0x04B8 */
	u32 star7_future_time_clock_duty_cycle;		/* 0x04BC */
	u32 star8_future_time_clock_duty_cycle;		/* 0x04C0 */
	u32 star9_future_time_clock_duty_cycle;		/* 0x04C4 */
	u32 star10_future_time_clock_duty_cycle;	/* 0x04C8 */
	u32 star11_future_time_clock_duty_cycle;	/* 0x04CC */
	u32 star12_future_time_clock_duty_cycle;	/* 0x04D0 */
	u32 _reserved_04D4_04FC[0xB];			/* 0x04D4 - 0x04FC */
	u32 future_time_buffer_control_enable;		/* 0x0500 */
	u32 _reserved_0504_050C[0x3];			/* 0x0504 - 0x050C */
	u32 future_time_buffer_size;			/* 0x0510 */
	u32 _reserved_0514;				/* 0x0514 */
	union {
		u32 future_time_partial_clear;		/* 0x0518 */
		u32 future_time_partial_clear_status;	/* 0x0518 */
	};
	u32 _reserved_051C_054C[0xD];			/* 0x051C - 0x054C */
	u32 future_time_buffer_high_word;		/* 0x0550 */
	u32 future_time_buffer_mid_word;		/* 0x0554 */
	u32 future_time_buffer_mid_low_word;		/* 0x0558 */
	u32 future_time_buffer_low_word;		/* 0x055C */
	u32 _reserved_0560_05FC[0x28];			/* 0x0560 - 0x05FC */
	u32 rtsi7_control_enable;			/* 0x0600 */
	u32 rtsi6_control_enable;			/* 0x0604 */
	u32 rtsi5_control_enable;			/* 0x0608 */
	u32 rtsi4_control_enable;			/* 0x060C */
	u32 rtsi3_control_enable;			/* 0x0610 */
	u32 rtsi2_control_enable;			/* 0x0614 */
	u32 rtsi1_control_enable;			/* 0x0618 */
	u32 rtsi0_control_enable;			/* 0x061C */
	u32 pfi2_control_enable;			/* 0x0620 */
	u32 pfi1_control_enable;			/* 0x0624 */
	u32 pfi0_control_enable;			/* 0x0628 */
	u32 _reserved_062C_0648[0x8];			/* 0x062C - 0x0648 */
	u32 star0_control_enable;			/* 0x064C */
	u32 star1_control_enable;			/* 0x0650 */
	u32 star2_control_enable;			/* 0x0654 */
	u32 star3_control_enable;			/* 0x0658 */
	u32 star4_control_enable;			/* 0x065C */
	u32 star5_control_enable;			/* 0x0660 */
	u32 star6_control_enable;			/* 0x0664 */
	u32 star7_control_enable;			/* 0x0668 */
	u32 star8_control_enable;			/* 0x066C */
	u32 star9_control_enable;			/* 0x0670 */
	u32 star10_control_enable;			/* 0x0674 */
	u32 star11_control_enable;			/* 0x0678 */
	u32 star12_control_enable;			/* 0x067C */
	u32 _reserved_0680_068C[0x4];			/* 0x0680 - 0x068C */
	u32 rtsi7_control_disable;			/* 0x0690 */
	u32 rtsi6_control_disable;			/* 0x0694 */
	u32 rtsi5_control_disable;			/* 0x0698 */
	u32 rtsi4_control_disable;			/* 0x069C */
	u32 rtsi3_control_disable;			/* 0x06A0 */
	u32 rtsi2_control_disable;			/* 0x06A4 */
	u32 rtsi1_control_disable;			/* 0x06A8 */
	u32 rtsi0_control_disable;			/* 0x06AC */
	u32 pfi2_control_disable;			/* 0x06B0 */
	u32 pfi1_control_disable;			/* 0x06B4 */
	u32 pfi0_control_disable;			/* 0x06B8 */
	u32 _reserved_06BC_06FC[0x11];			/* 0x06BC - 0x06FC */
	u32 rtsi7_decimation_count;			/* 0x0700 */
	u32 rtsi6_decimation_count;			/* 0x0704 */
	u32 rtsi5_decimation_count;			/* 0x0708 */
	u32 rtsi4_decimation_count;			/* 0x070C */
	u32 rtsi3_decimation_count;			/* 0x0710 */
	u32 rtsi2_decimation_count;			/* 0x0714 */
	u32 rtsi1_decimation_count;			/* 0x0718 */
	u32 rtsi0_decimation_count;			/* 0x071C */
	u32 pfi2_decimation_count;			/* 0x0720 */
	u32 pfi1_decimation_count;			/* 0x0724 */
	u32 pfi0_decimation_count;			/* 0x0728 */
	u32 _reserved_072C_074C[0x9];			/* 0x072C - 0x074C */
	u32 frequency_adjust_left_bound;		/* 0x0750 */
	u32 frequency_adjust_right_bound;		/* 0x0754 */
	u32 servo_control_future_time_left_bound;	/* 0x0758 */
	u32 servo_control_future_time_right_bound;	/* 0x075C */
	u32 servo_control_enable;			/* 0x0760 */
	u32 servo_phase_adjust_high_word;		/* 0x0764 */
	u32 servo_phase_adjust_low_word;		/* 0x0768 */
	u32 freq_comp_nominal;				/* 0x076C */
	u32 star0_decimation_count;			/* 0x0770 */
	u32 star1_decimation_count;			/* 0x0774 */
	u32 star2_decimation_count;			/* 0x0778 */
	u32 star3_decimation_count;			/* 0x077C */
	u32 star4_decimation_count;			/* 0x0780 */
	u32 star5_decimation_count;			/* 0x0784 */
	u32 star6_decimation_count;			/* 0x0788 */
	u32 star7_decimation_count;			/* 0x078C */
	u32 star8_decimation_count;			/* 0x0790 */
	u32 star9_decimation_count;			/* 0x0794 */
	u32 star10_decimation_count;			/* 0x0798 */
	u32 star11_decimation_count;			/* 0x079C */
	u32 star12_decimation_count;			/* 0x07A0 */
	u32 _reserved_07A4_07FC[0x17];			/* 0x07A4 - 0x07FC */
	u8 config_start;				/* 0x0800 */
	u8 _reserved_0801;				/* 0x0801 */
	u16 _reserved_0802;				/* 0x0802 */
	u32 _reserved_0804_09FC[0x7F];			/* 0x0804 - 0x09FC */
	u32 star0_control_disable;			/* 0x0A00 */
	u32 star1_control_disable;			/* 0x0A04 */
	u32 star2_control_disable;			/* 0x0A08 */
	u32 star3_control_disable;			/* 0x0A0C */
	u32 star4_control_disable;			/* 0x0A10 */
	u32 star5_control_disable;			/* 0x0A14 */
	u32 star6_control_disable;			/* 0x0A18 */
	u32 star7_control_disable;			/* 0x0A1C */
	u32 star8_control_disable;			/* 0x0A20 */
	u32 star9_control_disable;			/* 0x0A24 */
	u32 star10_control_disable;			/* 0x0A28 */
	u32 star11_control_disable;			/* 0x0A2C */
	u32 star12_control_disable;			/* 0x0A30 */
	u32 _reserved_0A34_0A68[0xE];			/* 0x0A34 - 0x0A68 */
	u32 star0_future_time_clock_period;		/* 0x0A6C */
	u32 star1_future_time_clock_period;		/* 0x0A70 */
	u32 star2_future_time_clock_period;		/* 0x0A74 */
	u32 star3_future_time_clock_period;		/* 0x0A78 */
	u32 star4_future_time_clock_period;		/* 0x0A7C */
	u32 star5_future_time_clock_period;		/* 0x0A80 */
	u32 star6_future_time_clock_period;		/* 0x0A84 */
	u32 star7_future_time_clock_period;		/* 0x0A88 */
	u32 star8_future_time_clock_period;		/* 0x0A8C */
	u32 star9_future_time_clock_period;		/* 0x0A90 */
	u32 star10_future_time_clock_period;		/* 0x0A94 */
	u32 star11_future_time_clock_period;		/* 0x0A98 */
	u32 star12_future_time_clock_period;		/* 0x0A9C */
	u32 _reserved_0AA0_0AC4[0xA];			/* 0x0AA0 - 0x0AC4 */

	/* pxi6683x specific registers below */
	u32 _reserved_0AC8_0AFC[0xE];			/* 0x0AC8 - 0x0AFC */
	u32 gps_tx_buffer;				/* 0x0B00 */
	u32 gps_rx_buffer;				/* 0x0B04 */
	u32 gps_serial_buffer_size;			/* 0x0B08 */
	u32 gps_baud_control;				/* 0x0B0C */
	u32 gps_control_enable;				/* 0x0B10 */
	u32 gps_control_disable;			/* 0x0B14 */
	u32 gps_rx_buffer_watermark;			/* 0x0B18 */
	u32 gps_tx_buffer_watermark;			/* 0x0B1C */
	u32 gps_fifo_status;				/* 0x0B20 */
	u32 gps_antenna;				/* 0x0B24 */
	u32 _reserved_0B28_0B2C[0x2];			/* 0x0B28 - 0x0B2C */
	u32 irig_control_enable;			/* 0x0B30 */
	u32 irig_control_disable;			/* 0x0B34 */
	u32 gps_pps_ts_high_word;			/* 0x0B38 */
	u32 gps_pps_ts_low_word;			/* 0x0B3C */
	u32 gps_pps_latency;				/* 0x0B40 */
	u32 _reserved_0B44_0B4C[0x3];			/* 0x0B44 - 0x0B4C */
	u32 irig_decodedc_latency;			/* 0x0B50 */
	u32 irig_decodeam_latency;			/* 0x0B54 */
	u32 _reserved_0B58_0BFC[0x2A];			/* 0x0B58 - 0x0BFC */
	u32 dac_ctrl_reg;				/* 0x0C00 */
	u32 _reserved_0C04_0C3C[0xF];			/* 0x0C04 - 0x0C3C */
	u32 genet_transmit_latency;			/* 0x0C40 */
	u32 genet_receive_latency;			/* 0x0C44 */
	u32 _reserved_0C48_0EFC[0xAE];			/* 0x0C48 - 0x0EFC */
	u32 timing_and_sync_reset_reg;			/* 0x0F00 */
	u32 _register_address_invalid;			/* 0x0F04 */
	u32 _reserved_0F08_0FFC[0x3E];			/* 0x0F08 - 0x0FFC */

	/* following pci register names here only to allow compilation */
	u32 input_timestamp_buffer_high_word;
	u32 input_timestamp_buffer_mid_word;
	u32 input_timestamp_buffer_low_word;
};

#endif /* NISYNC_REG_H_ */
